Class: FastaFile
- Inherits:
-
File
- Object
- File
- FastaFile
- Defined in:
- lib/parse_fasta/fasta_file.rb
Overview
Provides simple interface for parsing fasta format files.
Instance Method Summary collapse
-
#each_record(separate_lines = nil) {|header, sequence| ... } ⇒ Object
Analagous to File#each_line, #each_record is used to go through a fasta file record by record.
Instance Method Details
#each_record(separate_lines = nil) {|header, sequence| ... } ⇒ Object
Analagous to File#each_line, #each_record is used to go through a fasta file record by record.
50 51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/parse_fasta/fasta_file.rb', line 50 def each_record(separate_lines=nil) if separate_lines self.each("\n>") do |line| header, sequence = parse_line_separately(line) yield(header.strip, sequence) end else self.each("\n>") do |line| header, sequence = parse_line(line) yield(header.strip, Sequence.new(sequence)) end end end |