Class: FastaFile
- Inherits:
-
File
- Object
- File
- FastaFile
- Defined in:
- lib/parse_fasta/fasta_file.rb
Overview
Provides simple interface for parsing fasta format files.
Instance Method Summary collapse
-
#each_record {|header, sequence| ... } ⇒ Object
Analagous to File#each_line, #each_record is used to go through a fasta file record by record.
Instance Method Details
#each_record {|header, sequence| ... } ⇒ Object
Analagous to File#each_line, #each_record is used to go through a fasta file record by record.
35 36 37 38 39 40 |
# File 'lib/parse_fasta/fasta_file.rb', line 35 def each_record self.each("\n>") do |line| header, sequence = parse_line(line) yield(header.strip, Sequence.new(sequence)) end end |