Module: ParseFasta
- Defined in:
- lib/parse_fasta/version.rb,
lib/parse_fasta.rb
Overview
Copyright 2014, 2015 Ryan Moore Contact: [email protected]
This file is part of parse_fasta.
parse_fasta is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
parse_fasta is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with parse_fasta. If not, see <www.gnu.org/licenses/>.
Defined Under Namespace
Classes: DataFormatError
Constant Summary collapse
- VERSION =
"1.7.0"